#[repr(transparent)]pub struct Databufstart(pub u32);Expand description
USB Data buffer start address
Tuple Fields
0: u32Implementations
Sourceimpl Databufstart
impl Databufstart
Sourcepub const fn da_buf_fixed(&self) -> u32
pub const fn da_buf_fixed(&self) -> u32
The fixed portion of the data buffer start address.
Sourcepub const fn set_da_buf_fixed(&mut self, val: u32)
pub const fn set_da_buf_fixed(&mut self, val: u32)
The fixed portion of the data buffer start address.
Sourcepub const fn set_da_buf(&mut self, val: u16)
pub const fn set_da_buf(&mut self, val: u16)
Programmable portion of the data buffer start address.