nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Devcmdstat

Struct Devcmdstat 

#[repr(transparent)]
pub struct Devcmdstat(pub u32);
USB Device Command/Status register

Tuple Fields

0: u32

Implementations

Source

impl Devcmdstat

pub const fn dev_addr(&self) -> u8

USB device address.

pub const fn set_dev_addr(&mut self, val: u8)

USB device address.

pub const fn dev_en(&self) -> bool

USB device enable.

pub const fn set_dev_en(&mut self, val: bool)

USB device enable.

pub const fn setup(&self) -> bool

SETUP token received.

pub const fn set_setup(&mut self, val: bool)

SETUP token received.

pub const fn force_needclk(&self) -> bool

Forces the NEEDCLK output to always be on:.

pub const fn set_force_needclk(&mut self, val: bool)

Forces the NEEDCLK output to always be on:.

pub const fn force_vbus(&self) -> bool

If this bit is set to 1, the VBUS voltage indicators from the PHY are overruled.

pub const fn set_force_vbus(&mut self, val: bool)

If this bit is set to 1, the VBUS voltage indicators from the PHY are overruled.

pub const fn lpm_sup(&self) -> bool

LPM Supported:.

pub const fn set_lpm_sup(&mut self, val: bool)

LPM Supported:.

pub const fn intonnak_ao(&self) -> bool

Interrupt on NAK for interrupt and bulk OUT EP:.

pub const fn set_intonnak_ao(&mut self, val: bool)

Interrupt on NAK for interrupt and bulk OUT EP:.

pub const fn intonnak_ai(&self) -> bool

Interrupt on NAK for interrupt and bulk IN EP:.

pub const fn set_intonnak_ai(&mut self, val: bool)

Interrupt on NAK for interrupt and bulk IN EP:.

pub const fn intonnak_co(&self) -> bool

Interrupt on NAK for control OUT EP:.

pub const fn set_intonnak_co(&mut self, val: bool)

Interrupt on NAK for control OUT EP:.

pub const fn intonnak_ci(&self) -> bool

Interrupt on NAK for control IN EP:.

pub const fn set_intonnak_ci(&mut self, val: bool)

Interrupt on NAK for control IN EP:.

pub const fn dcon(&self) -> bool

Device status - connect.

pub const fn set_dcon(&mut self, val: bool)

Device status - connect.

pub const fn dsus(&self) -> bool

Device status - suspend.

pub const fn set_dsus(&mut self, val: bool)

Device status - suspend.

pub const fn lpm_sus(&self) -> bool

Device status - LPM Suspend.

pub const fn set_lpm_sus(&mut self, val: bool)

Device status - LPM Suspend.

pub const fn lpm_rewp(&self) -> bool

LPM Remote Wake-up Enabled by USB host.

pub const fn set_lpm_rewp(&mut self, val: bool)

LPM Remote Wake-up Enabled by USB host.

pub const fn speed(&self) -> u8

This field indicates the speed at which the device operates: 00b: reserved 01b: full-speed 10b: high-speed 11b: super-speed (reserved for future use).

pub const fn set_speed(&mut self, val: u8)

This field indicates the speed at which the device operates: 00b: reserved 01b: full-speed 10b: high-speed 11b: super-speed (reserved for future use).

pub const fn dcon_c(&self) -> bool

Device status - connect change.

pub const fn set_dcon_c(&mut self, val: bool)

Device status - connect change.

pub const fn dsus_c(&self) -> bool

Device status - suspend change.

pub const fn set_dsus_c(&mut self, val: bool)

Device status - suspend change.

pub const fn dres_c(&self) -> bool

Device status - reset change.

pub const fn set_dres_c(&mut self, val: bool)

Device status - reset change.

pub const fn vbus_debounced(&self) -> bool

This bit indicates if VBUS is detected or not.

pub const fn set_vbus_debounced(&mut self, val: bool)

This bit indicates if VBUS is detected or not.

pub const fn phy_test_mode(&self) -> u8

This field is written by firmware to put the PHY into a test mode as defined by the USB2.0 specification.

pub const fn set_phy_test_mode(&mut self, val: u8)

This field is written by firmware to put the PHY into a test mode as defined by the USB2.0 specification.