nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Eptoggle

Struct Eptoggle 

#[repr(transparent)]
pub struct Eptoggle(pub u32);
USB Endpoint toggle register

Tuple Fields

0: u32

Implementations

Source

impl Eptoggle

pub const fn toggle(&self) -> u32

Endpoint data toggle: This field indicates the current value of the data toggle for the corresponding endpoint.

pub const fn set_toggle(&mut self, val: u32)

Endpoint data toggle: This field indicates the current value of the data toggle for the corresponding endpoint.